app/soc/logic/models/club_admin.py
changeset 1085 0afbdd0905ef
parent 1062 f7ee38ebfe1c
child 1140 a8eaea0b268d
--- a/app/soc/logic/models/club_admin.py	Fri Jan 30 17:23:19 2009 +0000
+++ b/app/soc/logic/models/club_admin.py	Fri Jan 30 17:38:28 2009 +0000
@@ -43,14 +43,14 @@
                                 scope_logic=scope_logic)
 
   def _onCreate(self, entity):
     """Marks the Club for this Club Admin as active it's state is new.
     """
 
     club_entity = entity.scope
 
-    if club_entity.state == 'new':
+    if club_entity.status == 'new':
       # this club is new so mark as active
-      fields = {'state' : 'active'}
+      fields = {'status' : 'active'}
       club_logic.logic.updateEntityProperties(club_entity, fields)
 
     # call super
@@ -43,14 +43,14 @@
 
   def _onCreate(self, entity):
-    """Marks the Club for this Club Admin as active it's state is new.
+    """Marks the Club for this Club Admin as active it's status is new.
     """
 